# coding=utf-8

from django.core.management import BaseCommand
from api.tasks.personal_slide import same_city_group, same_city_clinical_doctor, same_city_kuaishang, \
    same_city_new_user_skill, same_city_toprank_doctor, same_city_toprank_hospital


class Command(BaseCommand):

    def handle(self, *args, **options):
        # same_city_group()
        # same_city_clinical_doctor(force=False)
        # same_city_kuaishang(force=False)
        same_city_new_user_skill(force=True)
        # same_city_toprank_doctor(force=False)
        # same_city_toprank_hospital(force=False)
